Module feedback

Module feedback 

Durable normalized evidence and replacement projections for skill analytics.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Structs

ApplyOutcome
BackfillPage
BackfillProgress
ChangeDiagnostic
ChangeReceipt
DeltaClaim
How much delta work one consumer worker claims and for how long.
DeltaLease
FactDelta
FactLease
FactsHealth
FactsProcessingService
FactsTotals
FeedbackFactsRepository
StoredFact

Enums

FactChangeState