pub struct SnapshotRangeJob {
pub operation_id: AnalyticsSnapshotJobId,
pub state: SnapshotJobState,
pub result: Option<FeedbackSnapshot>,
pub diagnostic: Option<String>,
}Expand description
A durable custom-range operation and its current result or diagnostic.
Fields
operation_id: AnalyticsSnapshotJobIdstate: SnapshotJobStateresult: Option<FeedbackSnapshot>diagnostic: Option<String>Trait Implementations
Sourceimpl Clone for SnapshotRangeJob
impl Clone for SnapshotRangeJob
Sourcefn clone(&self) -> SnapshotRangeJob
fn clone(&self) -> SnapshotRangeJob
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotRangeJob
impl Debug for SnapshotRangeJob
Sourceimpl<'de> Deserialize<'de> for SnapshotRangeJob
impl<'de> Deserialize<'de> for SnapshotRangeJob
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SnapshotRangeJob
impl JsonSchema for SnapshotRangeJob
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SnapshotRangeJob
impl RefUnwindSafe for SnapshotRangeJob
impl Send for SnapshotRangeJob
impl Sync for SnapshotRangeJob
impl Unpin for SnapshotRangeJob
impl UnsafeUnpin for SnapshotRangeJob
impl UnwindSafe for SnapshotRangeJob