pub struct SnapshotRangeRequest {
pub operation_id: AnalyticsSnapshotJobId,
pub resource_id: Option<ManagedResourceId>,
pub from_day: NaiveDate,
pub to_day: NaiveDate,
}Expand description
An idempotent bounded request for a UTC-day aggregate range.
Fields
operation_id: AnalyticsSnapshotJobIdresource_id: Option<ManagedResourceId>from_day: NaiveDateto_day: NaiveDateTrait Implementations
Sourceimpl Clone for SnapshotRangeRequest
impl Clone for SnapshotRangeRequest
Sourcefn clone(&self) -> SnapshotRangeRequest
fn clone(&self) -> SnapshotRangeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotRangeRequest
impl Debug for SnapshotRangeRequest
Sourceimpl<'de> Deserialize<'de> for SnapshotRangeRequest
impl<'de> Deserialize<'de> for SnapshotRangeRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SnapshotRangeRequest
impl JsonSchema for SnapshotRangeRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SnapshotRangeRequest
impl RefUnwindSafe for SnapshotRangeRequest
impl Send for SnapshotRangeRequest
impl Sync for SnapshotRangeRequest
impl Unpin for SnapshotRangeRequest
impl UnsafeUnpin for SnapshotRangeRequest
impl UnwindSafe for SnapshotRangeRequest